.. humblewx documentation master file, created by
   sphinx-quickstart on Wed Sep 30 08:41:34 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to humblewx's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   installing
   tutorial
   topics
   api
   release


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
